@@ -13,7 +13,7 @@
 #    under the License.
 
 from openstack_dashboard import exceptions
-import tuskarclient.exc as tuskarclient
+from tuskarclient.openstack.common.apiclient import exceptions as tuskarclient
 
 NOT_FOUND = exceptions.NOT_FOUND
 RECOVERABLE = exceptions.RECOVERABLE + (tuskarclient.ClientException,)
