@@ -13,7 +13,7 @@
 #    under the License.
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 import netaddr
 
 
@@ -25,8 +25,8 @@ class MACField(forms.fields.Field):
     def clean(self, value):
         try:
             return str(netaddr.EUI(
-                value, version=48, dialect=netaddr.mac_unix)).upper()
-        except netaddr.AddrFormatError:
+                value.strip(), version=48, dialect=netaddr.mac_unix)).upper()
+        except (netaddr.AddrFormatError, TypeError):
             raise forms.ValidationError(_(u'Enter a valid MAC address.'))
 
 
