@@ -12,38 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
 
-class InfrastructureOverview(horizon.PanelGroup):
-    slug = "infrastructure_overview"
-    name = _("Overview")
+class BasePanels(horizon.PanelGroup):
+    slug = "infrastructure"
+    name = _("Infrastructure")
     panels = (
-        'overview',
-    )
-
-
-class Deployment(horizon.PanelGroup):
-    slug = "deployment"
-    name = _("Deployment")
-    panels = (
-        'deployment.overview',
-        'deployment.controller',
-        'deployment.compute',
-        'deployment.object_storage',
-        'deployment.block_storage',
-    )
-
-
-class Resources(horizon.PanelGroup):
-    slug = "resources"
-    name = _("Resources")
-    panels = (
-        'resources.overview',
-        'resources.resource',
-        'resources.free',
+        'nodes',
+        'overcloud',
     )
 
 
@@ -51,11 +30,9 @@ class Infrastructure(horizon.Dashboard):
     name = _("Infrastructure")
     slug = "infrastructure"
     panels = (
-        InfrastructureOverview,
-        Deployment,
-        Resources,
+        BasePanels,
     )
-    default_panel = 'overview'
+    default_panel = 'overcloud'
     permissions = ('openstack.roles.admin',)
 
 
